@@ -52,6 +52,7 @@
 #include "egg-spawn.h"
 
 #include "gnome-desktop-item.h"
+#include "gnome-desktop-i18n.h"
 
 #ifdef HAVE_STARTUP_NOTIFICATION
 #define SN_API_NOT_YET_FROZEN
@@ -598,22 +599,6 @@ gnome_desktop_item_new_from_uri (const char *uri,
 		return NULL;
 	}	    	
 	
-	if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE &&
-	    info->type == GNOME_VFS_FILE_TYPE_REGULAR &&
-	    info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE &&
-	    strcmp (info->mime_type, "application/x-gnome-app-info") != 0) {
-		g_set_error (error,
-			     /* FIXME: better errors */
-			     GNOME_DESKTOP_ITEM_ERROR,
-			     GNOME_DESKTOP_ITEM_ERROR_INVALID_TYPE,
-			     _("File '%s' has invalid MIME type: %s"),
-			     uri, info->mime_type);
-
-		gnome_vfs_file_info_unref (info);
-
-		return NULL;
-	}		
-
 	if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MTIME)
 		mtime = info->mtime;
 	else
@@ -1424,6 +1409,9 @@ do_percent_subst (const GnomeDesktopItem *item,
 		}
 		break;
 	default:
+		/* Maintain special characters - e.g. "%20" */
+		if (g_ascii_isdigit (arg [1])) 
+			g_string_append_c (str, '%');
 		return FALSE;
 		break;
 	}
@@ -1502,7 +1490,7 @@ make_spawn_environment_for_sn_context (SnLauncherContext *sn_context,
 				       char             **envp)
 {
 	char **retval = NULL;
-	int    i;
+	int    i, j;
 	int    desktop_startup_id_len;
 
 	if (envp == NULL)
@@ -1515,15 +1503,18 @@ make_spawn_environment_for_sn_context (SnLauncherContext *sn_context,
 
 	desktop_startup_id_len = strlen ("DESKTOP_STARTUP_ID");
 	
-	for (i = 0; envp[i]; i++) {
+	for (i = 0, j = 0; envp[i]; i++) {
 		if (strncmp (envp[i], "DESKTOP_STARTUP_ID", desktop_startup_id_len) != 0)
-			retval[i] = g_strdup (envp[i]);
+		{
+			retval[j] = g_strdup (envp[i]);
+			++j;
+	        }
 	}
 
-	retval[i] = g_strdup_printf ("DESKTOP_STARTUP_ID=%s",
+	retval[j] = g_strdup_printf ("DESKTOP_STARTUP_ID=%s",
 				     sn_launcher_context_get_startup_id (sn_context));
-	++i;
-	retval[i] = NULL;
+	++j;
+	retval[j] = NULL;
 
 	return retval;
 }
