@@ -31,8 +31,7 @@
 #include <gtk/gtk.h>
 
 #include <libgnome/gnome-macros.h>
-#define GNOME_EXPLICIT_TRANSLATION_DOMAIN GETTEXT_PACKAGE
-#include <libgnome/gnome-i18n.h>
+#include "gnome-desktop-i18n.h"
 
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-icon-entry.h>
@@ -158,11 +157,6 @@ gnome_ditem_edit_class_init (GnomeDItemEditClass *klass)
         object_class->destroy = gnome_ditem_edit_destroy;
         gobject_class->finalize = gnome_ditem_edit_finalize;
         ditem_edit_class->changed = NULL;
-
-	/* Always get translations in UTF-8, needed if library is used
-	 * outside of gnome-core */
-        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 }
 
 enum {
@@ -230,7 +224,7 @@ setup_option (GnomeDItemEdit *dee,
 		break;
 	}
 
-	if (select && selected)
+	if (select && !selected)
 		add_menuitem (menu, select, _(select), select, &selected);
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (dee->_priv->type_option), menu);
@@ -556,7 +550,9 @@ translations_add (GtkWidget      *button,
 	 * If we are editing the current language, change the name and
 	 * comment entries on the easy page as well.
 	 */
-	locale = gnome_desktop_item_get_attr_locale (dee->_priv->ditem, "Name");
+	locale = gnome_desktop_item_get_attr_locale (gnome_ditem_edit_get_ditem (dee),
+						     "Name");
+
 	if ((locale && !strcmp (locale, lang)) || (!locale && !strcmp (lang, "C"))) {
 		gtk_entry_set_text (
 			GTK_ENTRY (dee->_priv->name_entry), name);
